******************************************************************************
* *
* TEXAS INSTRUMENTS INCORPORATED
* Standard Linear and Logic Group
* HSPICE Model for SN74AUC16240
* PROPERTY OF TEXAS INSTRUMENTS INCORPORATED. UNAUTHORIZED
* REPRODUCTION AND/OR DISTRIBUTION IS STRICTLY PROHIBITED.
*
* THIS PRODUCT IS PROTECTED UNDER COPYRIGHT LAW.
* CREATED 2007, (C) COPYRIGHT 2007, TEXAS INSTRUMENTS
* INCORPORATED, ALL RIGHTS RESERVED
*
* UNLESS THERE IS A SIGNED, WRITTEN AGREEMENT TO THE
* CONTRARY, TEXAS INSTRUMENTS (TI) IS PROVIDING THE IBIS
* MODELS AND WITHOUT ANY WARRANTY, EXPRESSED OR
* IMPLIED. TI ASSUMES NO LIABILITY FOR:
* 1) THE ACCURACY OF THE HSPICE MODELS PROVIDED TO YOUR
* COMPANY;
* 2) THE PROPER FUNCTIONING OF THESE HSPICE MODELS IN YOUR
* DESIGN OR FOR ANY RESULTING APPLICATIONS; OR
* 3) INFRINGEMENT OF PATENTS, COPYRIGHTS OR INTELLECTUAL
* PROPERTY RIGHTS RESULTING FROM YOUR USE OF THESE HSPICE
* MODELS.
*
* TI PROVIDES HSPICE MODELS AS A SERVICE TO OUR CUSTOMERS.
* YOU AND YOUR COMPANY SHALL NOT DISTRIBUTE, SELL OR GIVE
* THESE MODELS TO ANYONE ELSE WITHOUT PRIOR WRITTEN
* PERMISSION FROM TI.
*
* TI RESERVES THE RIGHT TO MAKE CHANGES TO OUR PRODUCTS OR
* TO DISCONTINUE ANY SEMICONDUCTOR PRODUCT OR SERVICE
* WITHOUT NOTICE, AND ADVISES OUR CUSTOMERS TO OBTAIN THE
* LATEST VERSION OF RELEVANT INFORMATION TO VERIFY, BEFORE
* PLACING ORDERS, THAT THE INFORMATION BEING RELIED ON IS
* CURRENT.
*
* PLEASE BE AWARE THAT YOUR RECEIPT AND USE OF THE HSPICE
* INFORMATION PROVIDED SHALL SERVE AS ACCEPTANCE OF THESE
* TERMS AND CONDITIONS. IF YOU DO NOT ACCEPT THESE TERMS,
* YOU SHOULD RETURN OR DESTROY THE HSPICE MODELS AND ANY
* OTHER ACCOMPANYING INFORMATION IMMEDIATELY.
************************************************************************
**** HSPICE EXECUTION OPTIONS ****
************************************************************************
*
.OPTIONS POST $ Enables HSPLOT interface
.OPTIONS ACCT OPTS $ Prints stats & option values used
.OPTIONS SPICE=1 $ Forces Berkeley compatibility
.OPTIONS GMIN=1E-10 $ Lowest allowable conductance values
.OPTIONS GMINDC=1E-10
.OPTIONS ITL1=400 $ Maximum DC iteration limit
.OPTIONS ITL4=40 $ Maximum transient iterations/timestep
.OPTIONS ITL5=0 $ No limit to total transient iterations
***********************************************************************
.OPTIONS search='./'

***********************************************************************
******Top level Subcircuit call (device call)
***********************************************************************
* .INCLUDE 'sn74auc16240.inc'
X__SN74AUC16240 X_1NOE X_1Y1 X_1Y2 GND X_1Y3 X_1Y4 VCC X_2Y1 X_2Y2 GND X_2Y3
+ X_2Y4 X_3Y1 X_3Y2 GND X_3Y3 X_3Y4 VCC X_4Y1 X_4Y2 GND X_4Y3 X_4Y4 X_4NOE
+ X_3NOE X_4A4 X_4A3 GND X_4A2 X_4A1 VCC X_3A4 X_3A3 GND X_3A2 X_3A1 X_2A4
+ X_2A3 GND X_2A2 X_2A1 VCC X_1A4 X_1A3 GND X_1A2 X_1A1 X_2NOE SN74AUC16240
*** PULSE PARAMETERS ***
.param PFREQ1=10MEG $ 1st pulse (clk) frequency
.param PRFT19=2ns $ rise/fall time
.param PDELAY1=5ns $ delay of 1st pulse
.param PVIN=2.5 $ input voltage
.param PVT=1.25 $ input threshold voltage
.param PMAX=15ns $ max SPICE delay time
.param PRFT='(PRFT19/0.8)' $ convert rise/fall time to 100$
.param PPD1='(1/PFREQ1)' $ period of 1st pulse
.param PPW1='((PPD1 - (PRFT*2))/2)' $ pulse width of 1st pulse

*** TRANSIENT START & START PARAMETERS ***
.param PSTART='PDELAY1' $ time input starts to transition.
.param PSTOP='PSTART+80n' $
.TRAN 0.05n 'PSTOP' 'PSTART' 0.05n
.PRINT TRAN v(DATA)

* SET CONTROL INPUTS TO ENABLE OUTPUT
VC0 X_1NOE 0 pulse 0 'PVIN' 'PDELAY1' 'PRFT' 'PRFT' 38ns 80ns
VC1 X_2NOE 0 DC 0
VC2 X_3NOE 0 DC 0
VC3 X_4NOE 0 DC 0


*** SET INPUT AND TEST OUTPUT TO GO LOW ****
VI0 X_1A1 0 pulse 0 'PVIN' 'PDELAY1' 'PRFT' 'PRFT' 18ns 40ns


* CHANGE TO THE OUTPUT NODE
VDATA X_1Y1 DATA DC 0
RLOAD DATA VCC 500

* VOLTAGE SUPPLIES
vnc nc 0 dc 0
rnc nc 0 100K

.param PVCC=2.5
.param PGND=0v
VVCC VCC 0 'PVCC'
VGND GND 0 'PGND'

.TEMP 40

* RESISTORS TO PREVENT DANGLING NODES
* R1G_1 X_1NOE 0 1G
* R1G_2 X_1Y1 0 1G
R1G_3 X_1Y2 0 1G
* R1G_4 GND 0 1G
R1G_5 X_1Y3 0 1G
R1G_6 X_1Y4 0 1G
* R1G_7 VCC 0 1G
R1G_8 X_2Y1 0 1G
R1G_9 X_2Y2 0 1G
* R1G_10 GND 0 1G
R1G_11 X_2Y3 0 1G
R1G_12 X_2Y4 0 1G
R1G_13 X_3Y1 0 1G
R1G_14 X_3Y2 0 1G
* R1G_15 GND 0 1G
R1G_16 X_3Y3 0 1G
R1G_17 X_3Y4 0 1G
* R1G_18 VCC 0 1G
R1G_19 X_4Y1 0 1G
R1G_20 X_4Y2 0 1G
* R1G_21 GND 0 1G
R1G_22 X_4Y3 0 1G
R1G_23 X_4Y4 0 1G
* R1G_24 X_4NOE 0 1G
* R1G_25 X_3NOE 0 1G
R1G_26 X_4A4 0 1G
R1G_27 X_4A3 0 1G
* R1G_28 GND 0 1G
R1G_29 X_4A2 0 1G
R1G_30 X_4A1 0 1G
* R1G_31 VCC 0 1G
R1G_32 X_3A4 0 1G
R1G_33 X_3A3 0 1G
* R1G_34 GND 0 1G
R1G_35 X_3A2 0 1G
R1G_36 X_3A1 0 1G
R1G_37 X_2A4 0 1G
R1G_38 X_2A3 0 1G
* R1G_39 GND 0 1G
R1G_40 X_2A2 0 1G
R1G_41 X_2A1 0 1G
* R1G_42 VCC 0 1G
R1G_43 X_1A4 0 1G
R1G_44 X_1A3 0 1G
* R1G_45 GND 0 1G
R1G_46 X_1A2 0 1G
* R1G_47 X_1A1 0 1G
* R1G_48 X_2NOE 0 1G

.END
